#if defined __APPLE__
#  include "SamplesOSX.h"
#else
#  include "sample.h"
#endif

#include "sample_common.h"
#include "sprk.h"

#ifdef SPRK_PUBLISH_SUPPORTED
#include "sprk_exchange.h"
#include "sprk_publish.h"
#endif

#include <iostream>

using namespace HPS;

void Sample::Publish_Widgets(WindowKey wk, Canvas canvas, View view, Model model, SegmentKey modelKey)
{
#ifdef SPRK_PUBLISH_SUPPORTED

	try
	{
		/* Sample: Publish_Widgets
		* This sample will show you how to:
		* - Create a PDF file with widgets using HOOPS Publish
		* - Output a the file through Publish and check for IO exceptions
		*
		* Read more about the topics covered in this sample in our Programming Guide
		* - Integration with HOOPS Publish */

		HPS::Publish::PageKit pageKit;             // corresponds to a page inside the PDF
		HPS::Publish::DocumentKit documentKit;     // corresponds to the document itself as a whole
		
		// the text that will exist next to the checkbox
		Publish::TextKit text;
		text.SetText("checkbox");
		pageKit.AddText(text, HPS::IntRectangle(140, 260, 400, 450));
		
		// setting up the checkbox
		Publish::CheckBoxKit checkBoxKit = Publish::CheckBoxKit::GetDefault();
		checkBoxKit.SetVisibility(true).
			SetTextColor(RGBColor(0, 0, 0)).
			SetFillColor(RGBColor(0.5f, 0.5f, 0.5f)).
			SetName("cb1").
			SetDefaultState(true);

		// checkboxes can be any size, as specified by the IntRectangle. this one will be fairly large
		pageKit.AddCheckBox(checkBoxKit, HPS::IntRectangle(10, 120, 400, 450));

		// add a list button to the page
		Publish::ListBoxKit list_box_kit;
		HPS::UTF8Array displayed_contents;
		HPS::UTF8Array exported_contents;
		displayed_contents.push_back("value 1");
		displayed_contents.push_back("value 2");
		displayed_contents.push_back("value 3");
		exported_contents.push_back("e1");
		exported_contents.push_back("e2");
		exported_contents.push_back("e3");
		list_box_kit.SetName("lb2").
			SetContents(displayed_contents, exported_contents);
		pageKit.AddListBox(list_box_kit, HPS::IntRectangle(10, 60, 300, 350));
		
		// add button to the page
		Publish::ButtonKit buttonKit;
		buttonKit.SetLabel("This is a page button")
			.SetLabelPosition(Publish::Label::Position::OnTop)
			.SetHighlighting(Publish::Highlighting::Mode::Push)
			.SetVisibility(true)
			.SetFont(Publish::Text::Font::Name::TimesRoman)
			.SetFontSize(8)
			.SetTextColor(RGBColor(0, 0, 0))
			.SetFillColor(RGBColor(0.5f, 0.5f, 0.5f))
			.SetName("execute_button"); // setting the name of the button is required!
		pageKit.AddButton(buttonKit, HPS::IntRectangle(10, 120, 500, 550));
		
		// will print "hello world" to the Javascript console
		pageKit.SetJavaScriptActionByField("execute_button", "console.println(\"hello world\");", HPS::Publish::Source::Type::Code);

		documentKit.AddPage(pageKit);

		HPS::Publish::File::Export(documentKit, OUTPUT_FOLDER + "/publish_widgets.pdf", Publish::ExportOptionsKit());
	
	}
	catch (IOException e)
	{
		std::cout << e.what() << std::endl;
	}

#else
	model.GetSegmentKey().InsertText(Point(0, 0, 0), "HOOPS Publish is not supported on this platform");
	model.GetSegmentKey().GetVisibilityControl().SetText(true);
	model.GetSegmentKey().GetTextAttributeControl().SetAlignment(HPS::Text::Alignment::Center);
#endif
}
